<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>WindowZoom</name>
    <message>
        <location filename="../WindowZoomInit.js" line="+2"/>
        <source>&amp;Window Zoom</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Okno powiększenia</translatorcomment>
        <translation>&amp;Okno przybliżenia</translation>
    </message>
</context>
</TS>
